var ffmod = require('./FatFractal_nodeWrapper.js');
var ff = new ffmod.FatFractal();
ff.setSimulateCookies(true);

var baseUrl = "http://localhost:8080/mazes/";

ff.setBaseUrl(baseUrl);
ff.setSSLUrl(baseUrl);

var fs = require('fs');

function MAMaze(data) 
{
 	this.guid = data.guid;
  	this.clazz = data.clazz;
	this.ffUrl = data.ffUrl;
   	this.mazeId = data.mazeId;
   	this.name = data.name;
   	this.user = data.user;
	this.averageRating = data.averageRating;
   	this.ratingCount = data.ratingCount;
   	this.public = data.public;
   	this.modifiedAt = data.modifiedAt;

    return this;
}

function MAMazeProgress(data) 
{
 	this.guid = data.guid;
  	this.clazz = data.clazz;
	this.ffUrl = data.ffUrl;
   	this.mazeProgressId = data.mazeProgressId;
   	this.user = data.user;
   	this.maze = data.maze;
   	this.started = data.started;
   	this.foundExit = data.foundExit;

    return this;
}

function MAMazeRating(data) 
{
 	this.guid = data.guid;
  	this.clazz = data.clazz;
	this.ffUrl = data.ffUrl;
   	this.mazeRatingId = data.mazeRatingId;
   	this.user = data.user;
   	this.maze = data.maze;
   	this.userRating = data.userRating;

    return this;
}

Clear();

function Clear()
{
	ff.login("system", "password", function (user) 
	{
		var objects = new Array();
	
		ff.getArrayFromUri("/MAMaze", function(mazes) 
		{
			objects = objects.concat(mazes);
		
			ff.getArrayFromUri("/MAMazeProgress", function(progresses) 
			{
				objects = objects.concat(progresses);

				ff.getArrayFromUri("/MAMazeRating", function(ratings) 
				{
					objects = objects.concat(ratings);

					if (objects.length == 0)
					{
						Seed();						
					}
					else
					{
						for (var i = 0; i < objects.length; i++) 
						{
							ff.deleteObj(objects[i]);
					
							if (i == objects.length - 1)
							{
								Seed();
							}
						}
					}
				}); 
			}); 
		}); 
	});
}

function Seed()
{
	ff.login("TestUser1", "password", function (testUser1) 
	{
		ff.login("TestUser2", "password", function (testUser2) 
		{
			var maze1 = new MAMaze(JSON.parse('{"mazeId": "7DA873F9-2EA1-4B28-A3C5-E4007F576273", "name": "maze 1 - user 1 - public", "averageRating": 1.0, "ratingCount": 3, "public": true, "modifiedAt": ' + Date.parse("01-01-2013 00:00:00 Z") + '}'));
			maze1.user = testUser1;
			ff.createObjAtUri(maze1, "/MAMaze", function(data, responseText) 
			{
				var maze2 = new MAMaze(JSON.parse('{"mazeId": "1837245C-F3F5-4810-A22D-B6BDF7C88499", "name": "maze 2 - user 1 - public", "averageRating": 2.0, "ratingCount": 3, "public": true, "modifiedAt": ' + Date.parse("02-01-2013 00:00:00 Z") + '}'));
				maze2.user = testUser1;
				ff.createObjAtUri(maze2, "/MAMaze", function(data, responseText) 
				{
					var maze3 = new MAMaze(JSON.parse('{"mazeId": "D7B12EE4-3BB9-4715-A01C-4909A4D6755C", "name": "maze 3 - user 1 - not public", "averageRating": 3.0, "ratingCount": 3, "public": false, "modifiedAt": ' + Date.parse("03-01-2013 00:00:00 Z") + '}'));
					maze3.user = testUser1;
					ff.createObjAtUri(maze3, "/MAMaze", function(data, responseText) 
					{
						var maze4 = new MAMaze(JSON.parse('{"mazeId": "F40A6840-3BFB-423D-A432-9755A838D90B", "name": "maze 4 - user 2 - public", "averageRating": 4.0, "ratingCount": 3, "public": true, "modifiedAt": ' + Date.parse("04-01-2013 00:00:00 Z") + '}'));
						maze4.user = testUser2;
						ff.createObjAtUri(maze4, "/MAMaze", function(data, responseText) 
						{
							var maze5 = new MAMaze(JSON.parse('{"mazeId": "797A7ACA-621F-4BE7-B018-F176D9EA4205", "name": "maze 5 - user 2 - public", "averageRating": 5.0, "ratingCount": 3, "public": true, "modifiedAt": ' + Date.parse("05-01-2013 00:00:00 Z") + '}'));
							maze5.user = testUser2;
							ff.createObjAtUri(maze5, "/MAMaze", function(data, responseText) 
							{
								var mazeProgress1 = new MAMazeProgress(JSON.parse('{"mazeProgressId": "F5883717-AA5C-4F3D-BCF4-0F5AF15BAC9D", "started": true, "foundExit": true}'));
								mazeProgress1.user = testUser1;
								mazeProgress1.maze = maze1;
								ff.createObjAtUri(mazeProgress1, "/MAMazeProgress");

								var mazeProgress2 = new MAMazeProgress(JSON.parse('{"mazeProgressId": "FDAC4712-1C63-40E2-8FCB-A8D78BABA4EA", "started": true, "foundExit": true}'));
								mazeProgress2.user = testUser1;
								mazeProgress2.maze = maze2;
								ff.createObjAtUri(mazeProgress2, "/MAMazeProgress");

								var mazeProgress3 = new MAMazeProgress(JSON.parse('{"mazeProgressId": "9BA5244F-E2D6-4D98-881D-402B06D9AED1", "started": true, "foundExit": true}'));
								mazeProgress3.user = testUser2;
								mazeProgress3.maze = maze4;
								ff.createObjAtUri(mazeProgress3, "/MAMazeProgress");


								var mazeRating1 = new MAMazeRating(JSON.parse('{"mazeRatingId": "5EB02540-FCCE-4352-907E-1035571EDB43", "userRating": 1}'));
								mazeRating1.maze = maze1;
								mazeRating1.user = testUser1;
								ff.createObjAtUri(mazeRating1, "/MAMazeRating");

								var mazeRating2 = new MAMazeRating(JSON.parse('{"mazeRatingId": "5AE9853D-E2A1-4B31-8D15-1F9D14AB9BF9", "userRating": 3}'));
								mazeRating2.maze = maze2;
								mazeRating2.user = testUser1;
								ff.createObjAtUri(mazeRating2, "/MAMazeRating");

								var mazeRating3 = new MAMazeRating(JSON.parse('{"mazeRatingId": "29E408D7-A09B-4268-A877-3DCE1E0EB224", "userRating": 5}'));
								mazeRating3.maze = maze5;
								mazeRating3.user = testUser2;
								ff.createObjAtUri(mazeRating3, "/MAMazeRating");
							});
						});
					});
				});
			});
		});
	});
}

