var ffmod = require('./FatFractal_nodeWrapper.js');
var ff = new ffmod.FatFractal();
ff.setSimulateCookies(true);

var baseUrl = "http://localhost:8080/mazes/";
//var baseUrl = "https://muis.fatfractal.com/mazes/";

ff.setBaseUrl(baseUrl);
ff.setSSLUrl(baseUrl);

var fs = require('fs');

Clear();

function Clear()
{
	ff.login("system", "password", function (user) 
	{
		var objects = new Array();
	
		ff.getArrayFromUri("/MASound", function(sounds) 
		{
			objects = objects.concat(sounds);
		
			ff.getArrayFromUri("/MATexture", function(textures) 
			{
				objects = objects.concat(textures);

				ff.getArrayFromUri("/MALatestVersion", function(latestVersions) 
				{
					objects = objects.concat(latestVersions);

					ff.getArrayFromUri("/MAUserCounter", function(userCounters) 
					{
						objects = objects.concat(userCounters);

						if (objects.length == 0)
						{
							Seed();						
						}
						else
						{
							for (var i = 0; i < objects.length; i++) 
							{
								ff.deleteObj(objects[i]);
					
								if (i == objects.length - 1)
								{
									Seed();
								}
							}
						}
					}); 
				}); 
			}); 
		}); 
	});
}

function MALatestVersion(data) 
{
 	this.guid = data.guid;
  	this.clazz = data.clazz;
	this.ffUrl = data.ffUrl;
   	this.latestVersionId = data.latestVersionId;
   	this.latestVersion = data.latestVersion;

    return this;
}

function MAUserCounter(data) 
{
 	this.guid = data.guid;
  	this.clazz = data.clazz;
	this.ffUrl = data.ffUrl;
	this.userCounterId = data.userCounterId;
   	this.count = data.count;

    return this;
}

function Seed()
{
	ff.login("system", "password", function (user) 
	{
		addSound(0);
		addTexture(0);
	
		var maLatestVersion = new MALatestVersion(JSON.parse('{"latestVersionId": "7C493810-64F3-48B4-8B24-8D9B67FF52E1", "latestVersion": 4.1}'));
    
		ff.createObjAtUri(maLatestVersion, "/MALatestVersion", function(data, responseText) 
		{
			console.log("Set latest version");		
		}, function(statusCode, responseText)
		{
			console.error("Error "+ statusCode + ": " + JSON.parse(responseText).statusMessage);
		});

		var maUserCounter = new MAUserCounter(JSON.parse('{"userCounterId": "609CD89E-CC45-4048-B766-1E97815DFD9F", "count": 1}'));
    
		ff.createObjAtUri(maUserCounter, "/MAUserCounter", function(data, responseText) 
		{
			console.log("Set user counter");		
		}, function(statusCode, responseText)
		{
			console.error("Error "+ statusCode + ": " + JSON.parse(responseText).statusMessage);
		});
	});
}

function MASound(data) 
{
 	this.guid = data.guid;
  	this.clazz = data.clazz;
	this.ffUrl = data.ffUrl;
   	this.soundId = data.soundId;
   	this.name = data.name;

    return this;
}

var sounds = JSON.parse(fs.readFileSync('./sounds.json'));

function addSound(i)
{
    var maSound = new MASound(sounds[i]);

	ff.createObjAtUri(maSound, "/MASound", function(data, responseText) 
	{
		console.log("Added sound named " + data.name);
		
		if (i < sounds.length - 1)
		{
			addSound(i + 1);
		}
	}, function(statusCode, responseText)
	{
		console.error("Error "+ statusCode + ": " + JSON.parse(responseText).statusMessage);
	});	
}

function MATexture(data) 
{
 	this.guid = data.guid;
  	this.clazz = data.clazz;
	this.ffUrl = data.ffUrl;
   	this.textureId = data.textureId;
   	this.name = data.name;
   	this.width = data.width;
   	this.height = data.height;
   	this.repeats = data.repeats;
   	this.kind = data.kind;
   	this.order = data.order;

    return this;
}

var textures = JSON.parse(fs.readFileSync('./textures.json'));

function addTexture(i)
{
    var maTexture = new MATexture(textures[i]);

	ff.createObjAtUri(maTexture, "/MATexture", function(data, responseText) 
	{
		console.log("Added texture named " + data.name);
		
		if (i < textures.length - 1)
		{
			addTexture(i + 1);
		}
	}, function(statusCode, responseText)
	{
		console.error("Error "+ statusCode + ": " + JSON.parse(responseText).statusMessage);
	});	
}





